import { Injectable, UnauthorizedException } from '@nestjs/common'
import { PassportStrategy } from '@nestjs/passport'
import { ExtractJwt, Strategy } from 'passport-jwt'
import { JWT_SECRET } from './auth.module'
import { PlayersService } from 'src/players/players.service'
import { Player } from '@prisma/client'

@Injectable()
export class JwtStrategy extends PassportStrategy(Strategy, 'jwt') {
  constructor(private playersService: PlayersService) {
    super({
      jwtFromRequest: ExtractJwt.fromAuthHeaderAsBearerToken(),
      secretOrKey: JWT_SECRET,
    })
  }

  async validate(payload: { playerId: number }): Promise<Player> {
    const player = await this.playersService.findOne(payload.playerId)
    if (!player) {
      throw new UnauthorizedException()
    }
    return player
  }
}
