import { ApiProperty } from "@nestjs/swagger"
import { ChallengeAction } from "@prisma/client"
import { IsOptional } from "class-validator"

export class ChallengeActionEntity implements ChallengeAction {
  constructor(partial: Partial<ChallengeActionEntity>) {
    Object.assign(this, partial)
  }

  /**
   * Identifiant unique
   */
  id: number

  /**
   * Identifiant de læ joueur⋅se effectuant le défi
   */
  playerId: number

  /**
   * Identifiant du défi rattaché à l'action
   */
  challengeId: number

  /**
   * Est-ce que le défi a été réussi
   */
  success: boolean

  /**
   * Heure à laquelle le défi a été démarré
   */
  start: Date

  /**
   * Heure à laquelle le défi a été terminé
   */
  @IsOptional()
  end: Date | null = null

  /**
   * Heure à laquelle la pénalité a commencé, si applicable
   */
  penaltyStart: Date | null = null

  /**
   * Heure à laquelle la pénalité s'est terminée, si applicable
   */
  @IsOptional()
  penaltyEnd: Date | null = null

  /**
   * Identifiant de la course pendant laquelle le challenge est réalisé
   */
  runId: number
}
