import { ApiProperty } from "@nestjs/swagger"
import { IsNumber, IsOptional } from "class-validator"

export const DEFAULT_PAGE_NUMBER = 1
export const DEFAULT_PAGE_SIZE = 20

export class MetaPaginateOutputDto {
    @IsNumber()
    @ApiProperty()
    total: number
  
    @IsNumber()
    @ApiProperty()
    lastPage: number
  
    @IsNumber()
    @ApiProperty({ default: DEFAULT_PAGE_NUMBER })
    currentPage: number = DEFAULT_PAGE_NUMBER
  
    @IsNumber()
    @ApiProperty({ default: DEFAULT_PAGE_SIZE })
    totalPerPage: number = DEFAULT_PAGE_SIZE
  
    @IsOptional()
    @IsNumber()
    @ApiProperty({ required: false, nullable: true, default: null })
    prevPage?: number | null
  
    @IsOptional()
    @IsNumber()
    @ApiProperty({ required: false, nullable: true, default: null })
    nextPage?: number | null
  }
  
  export class PaginateOutputDto<T> {
    @ApiProperty({ isArray: true })
    data: T[]
  
    @ApiProperty()
    meta: MetaPaginateOutputDto
  }
  