import { ApiProperty } from "@nestjs/swagger"
import { MoneyUpdate, MoneyUpdateType } from "@prisma/client"
import { IsOptional } from "class-validator"

export class MoneyUpdateEntity implements MoneyUpdate {
  constructor (partial: Partial<MoneyUpdateEntity>) {
    Object.assign(this, partial)
  }

  /**
   * Identifiant unique de la mise à jour de solde
   */
  id: number

  /**
   * Joueur⋅se concerné⋅e par la mise à jour de solde
   */
  playerId: number

  /**
   * Montant de la modification du solde
   */
  amount: number

  /**
   * Type de modification de solde
   */
  reason: MoneyUpdateType

  /**
   * Identifiant de la réalisation de défi, si la mise à jour est liée à un défi
   */
  actionId: number | null = null

  /**
   * Identifiant du trajet acheté, si la mise à jour est liée à la réservation d'un train
   */
  tripId: string | null = null

  /**
   * Idenifiant de la course rattachée, si la mise à jour est liée à une nouvelle tentative de course
   */
  runId: number | null = null

  /**
   * Date et heure de la modification de solde
   */
  timestamp: Date
}
