import { Injectable } from '@nestjs/common'
import { Player } from '@prisma/client'
import { PrismaService } from 'src/prisma/prisma.service'
import * as bcrypt from 'bcrypt'
import { UpdatePasswordDto } from './dto/player_password.dto'
import { QueryPaginationDto } from 'src/common/dto/pagination-query.dto'
import { paginate } from 'src/common/utils/pagination.utils'

@Injectable()
export class PlayersService {
  constructor(private prisma: PrismaService) {}

  async findAll(queryPagination?: QueryPaginationDto): Promise<[Player[], number]> {
    return [
      await this.prisma.player.findMany({ ...paginate(queryPagination) }),
      await this.prisma.player.count()
    ]
  }

  async findOne(id: number): Promise<Player> {
    return await this.prisma.player.findUnique({ where: { id: id } })
  }

  async updatePassword(user: Player, { password }: UpdatePasswordDto): Promise<void> {
    const hashedPassword = await bcrypt.hash(password, 10)
    await this.prisma.player.update({
      where: { id: user.id },
      data: { password: hashedPassword }
    })
  }
}
