import { ApiProperty } from "@nestjs/swagger"
import { JsonValue } from "@prisma/client/runtime/library"
import { Type } from "class-transformer"
import { IsDate, IsInt, IsJSON, IsNumber, IsString, IsUUID } from "class-validator"

export class CreateTrainDto {
  @IsUUID()
  @ApiProperty({ description: "Identifiant du train, donné par l'identifiant de partage Interrail" })
  id: string

  @IsInt()
  @Type(() => Number)
  @ApiProperty({ description: "Identifiant de læ joueur⋅se effectuant le trajet" })
  playerId: number

  @IsNumber()
  @Type(() => Number)
  @ApiProperty({ description: "Distance estimée en mètres du trajet" })
  distance: number

  @IsString()
  @ApiProperty({ description: "Nom de la gare de départ" })
  from: string

  @IsString()
  @ApiProperty({ description: "Nom de la gare d'arrivée" })
  to: string

  @IsDate()
  @Type(() => Date)
  @ApiProperty({ description: "Date et heure de départ du train" })
  departureTime: Date

  @IsDate()
  @Type(() => Date)
  @ApiProperty({ description: "Date et heure d'arrivée du train" })
  arrivalTime: Date

  @IsJSON()
  @ApiProperty({ description: "Informations JSON supplémentaires transmises par Interrail" })
  infoJson: JsonValue
}
